@@ -1,7 +1,7 @@
 use crate::fs::{FileType, Metadata, OpenOptions};
 use crate::fs_utf8::{to_utf8, Dir, File};
 #[cfg(not(windows))]
-use rsix::fs::DirEntryExt;
+use rustix::fs::DirEntryExt;
 use std::{fmt, io};
 
 /// Entries returned by the `ReadDir` iterator.
@@ -82,12 +82,16 @@ impl DirEntry {
     /// Returns the bare file name of this directory entry without any other
     /// leading path component.
     ///
+    /// This function returns an `Err` in the case that the file name isn't
+    /// encodable as UTF-8.
+    ///
+    /// If the `arf_strings` feature is enabled, unencodable names are
+    /// translated to UTF-8 using `arf-strings`.
+    ///
     /// This corresponds to [`async_std::fs::DirEntry::file_name`].
     #[inline]
-    pub fn file_name(&self) -> String {
-        // Unwrap because we can assume that paths coming from the OS don't
-        // have embedded NULs.
-        to_utf8(self.cap_std.file_name()).unwrap().into()
+    pub fn file_name(&self) -> io::Result<String> {
+        Ok(to_utf8(self.cap_std.file_name())?.into())
     }
 }
 
